# PyDapi2
The *PyDapi2* library offers a Python implementation of the Dassym API version 2.

Dassym API version 2 aka **DAPI2** is the application programming interface (API) used to
control Dassym electronic boards.

This library was created to meet the internal needs of Dassym. It is distributed to help 
our partners to implement their own solutions working with Dassym electronic cards.

Version: 0.1.6 (2021-07-12)

This program is free software: you can redistribute it and/or modify 
it under the terms of the **GNU General Public License** as published by 
the Free Software Foundation, either version 3 of the License, or 
(at your option) any later version.

This program is distributed in the hope that it will be useful, 
but WITHOUT ANY WARRANTY; without even the implied warranty of 
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
GNU General Public License for more details. 

You can consult the GNU General Public License on <http://www.gnu.org/licenses/gpl-3.0.html>.


## Install

This installs a package that can be used from Python (import dapi2).

To install for all users on the system, administrator rights (root) may be required.

*PyDapi2* library requires [Python](https://www.python.org) 3.8 or later.

### From PyPI

*PyDapi2* can be installed from PyPI:

> python -m pip install PyDapi2

Use `python` or `python3` depending on your system.
Usually `python` on a *Windows* system and `python3` on a *GNU/Linux* system.


### From source

Download the archive from <https://github.com/dassym/PyDapi2/releases>.
Unpack the archive, enter the PyDapi2-x.y.z directory and run:

> python setup.py install 

Use `python` or `python3` depending on your system.
Usually `python` on a *Windows* system and `python3` on a *GNU/Linux* system.

